yt.frontends.stream.data_structures.StreamHierarchy.lock_grids_to_parents — The yt Project 3.2-dev documentation

# yt.frontends.stream.data_structures.StreamHierarchy.lock_grids_to_parents

`StreamHierarchy.` `lock_grids_to_parents`()

  This function locks grid edges to their parents.

  This is useful in cases where the grid structure may be somewhat irregular, or where setting the left and right edges is a lossy process. It is designed to correct situations where left/right edges may be set slightly incorrectly, resulting in discontinuities in images and the like.